\name{Ano}
\alias{Ano}
\title{Computes Forecast or Observed Anomalies}
\description{
  This function computes anomalies from any experimental or observational 
  matrix output from \code{Load()} and their climatologies output from 
  \code{Clim()}.
}
\usage{
  Ano(var, clim)
}
\arguments{
  \item{var}{
    Model or observational data:
      c(nmod/nexp/nobs, nmemb/nparam, nsdates, nltime) up to
      c(nmod/nexp/nobs, nmemb/nparam, nsdates, nltime, nlevel, nlat, nlon)
  }
  \item{clim}{
    Climatologies from clim:
      c(nmod/nexp/nobs, nltime) up to
      c(nmod/nexp/nobs, nltime, nlevel, nlat, nlon)
      or
      c(nmod/nexp/nobs, nmemb/nparam, nltime) up to
      c(nmod/nexp/nobs, nmemb/nparam, nltime, nlevel, nlat, nlon)
      or
      c(nmod/nexp/nobs, nmemb/nparam, nsdates, nltime) up to
      c(nmod/nexp/nobs, nmemb/nparam, nsdates, nltime, nlevel, nlat, nlon)
      depending on the options provided to \code{Clim()}
  }
}
\value{
  Matrix with same dimensions as var
}
\examples{
  startDates <- c('19901101', '19951101', '20001101')
  sampleData <- Load('tos', c('i00k'), c('ERSST'),  startDates,
                     nleadtime = 124, leadtimemin = 1, leadtimemax = 60, 
                     sampleperiod = 3, output = 'lonlat', latmin = -60,
                     latmax = 65, lonmin = 315, lonmax = 360)
  clim <- Clim(sampleData$mod, sampleData$obs)
  anomalies <- Ano(sampleData$mod, clim$clim_exp)
  print(dim(anomalies))
}
\author{
  History:
  0.1  -  2012-03  (V. Guemas, \email{virginie.guemas@ic3.cat})  -  Original code
  1.0  -  2013-09  (N. Manubens, \email{nicolau.manubens@ic3.cat})  -  Formatting to R CRAN
}
\keyword{datagen}
