\name{SelIndices}
\alias{SelIndices}
\title{
  Slices A Matrix Along A Dimension
}
\description{
  This function allows to select a subensemble from a matrix of any dimensions, 
  providing the dimension along which the user aims at cutting the input matrix
  and between which indices.
}
\usage{
  SelIndices(var, posdim, limits)
}
\arguments{
  \item{var}{
    A matrix of any dimensions.
  }
  \item{posdim}{
    The dimension along which a submatrix should be selected.
  }
  \item{limits}{
    The lower and upper indice of the selection along the posdim dimension.
  }
}
\value{
  The sliced matrix.
}
\examples{
  startDates <- c('19901101', '19951101', '20001101')
  sampleData <- Load('tos', c('i00k'), c('ERSST'),  startDates,
                     nleadtime = 124, leadtimemin = 1, leadtimemax = 60, 
                     sampleperiod = 3, output = 'lonlat', latmin = -60,
                     latmax = 65, lonmin = 315, lonmax = 360)
  dim_to_slice <- 4
  limits <- c(6, 15)
  slice <- SelIndices(sampleData$obs, dim_to_slice, limits)
  print(dim(slice))
}
\author{
  History:
  0.1  -  2011-04  (V. Guemas, \email{virginie.guemas@ic3.cat})  -  Original code
  1.0  -  2013-09  (N. Manubens, \email{nicolau.manubens@ic3.cat})  -  Formatting to CRAN
}
\keyword{datagen}
