\name{Smoothing}
\alias{Smoothing}
\title{
  Smoothes A Matrix Along A Dimension
}
\description{
  Smoothes a matrix of any number of dimensions up to 10 dimensions along one of its dimensions
}
\usage{
  Smoothing(var, runmeanlen = 12, numdimt = 4)
}
\arguments{
  \item{var}{
    Matrix to be smoothed along one of its dimension (typically the forecast time dimension).
  }
  \item{runmeanlen}{
    Running mean length in number of sampling units (typically months).
  }
  \item{numdimt}{
    Dimension to smooth.
  }
}
\value{
  Matrix with same the dimensions as var but smoothed along the numdimt
  dimension.
}
\examples{
  startDates <- c('19901101', '19951101', '20001101')
  sampleData <- Load('tos', c('i00k'), c('ERSST'),  startDates,
                     nleadtime = 124, leadtimemin = 1, leadtimemax = 60, 
                     sampleperiod = 3, output = 'lonlat', latmin = -60,
                     latmax = 65, lonmin = 315, lonmax = 360)
  clim <- Clim(sampleData$mod, sampleData$obs)
  ano_exp <- Ano(sampleData$mod, clim$clim_exp)
  mean_months <- 12
  dim_to_smooth <- 4  # Smooth along lead-times
  smooth_ano_exp <- Smoothing(ano_exp, mean_months, dim_to_smooth)
  print(dim(smooth_ano_exp))
}
\author{
  History:
  0.1  -  2011-03  (V. Guemas, \email{virginie.guemas@ic3.cat})  -  Original code
  1.0  -  2013-09  (N. Manubens, \email{nicolau.manubens@ic3.cat})  -  Formatting to R CRAN
}
\keyword{datagen}
