\name{Trend}
\alias{Trend}
\title{
  Computes Trends
}
\description{
  Computes the trend along the posTR dimension of the matrix var by least 
  square fitting, and the associated an error interval.
  Provide also the detrended data.
  The confidence interval relies on a student-T distribution.
}
\usage{
  Trend(var, posTR = 2, interval = 1)
}
\arguments{
  \item{var}{
    Matrix of any number of dimensions up to 10.
  }
  \item{posTR}{
    Position along which to compute the trend.
  }
  \item{interval}{
    Number of months/years between 2 points along posTR dimension.
    Default = 1. 
    The trend would be provided in number of units per month or year.
  }
}
\value{
  \item{$trend}{
    Same dimensions as var except along the posTR dimension which is replaced 
    by a length 3 dimension, corresponding to the lower limit of the  95\% 
    confidence interval, trends and the upper limit of the 95\% confidence 
    interval for each point of the matrix along all the other dimensions.
  }
  \item{$detrended}{
    Same dimensions as var with linearly detrended var along the posTR 
    dimension.
  }
}
\examples{
  startDates <- c('19901101', '19951101', '20001101')
  sampleData <- Load('tos', c('i00k'), c('ERSST'),  startDates,
                     nleadtime = 124, leadtimemin = 1, leadtimemax = 60, 
                     sampleperiod = 3, output = 'lonlat', latmin = -60,
                     latmax = 65, lonmin = 315, lonmax = 360)
  months_per_leadtime <- 3
  trend <- Trend(sampleData$obs[1, 1, , , , ], 2, months_per_leadtime)
  print(dim(trend$trend))
  print(dim(trend$detrended))
}
\author{
  History:
  0.1  -  2011-05  (V. Guemas, \email{virginie.guemas@ic3.cat})  -  Original code
  1.0  -  2013-09  (N. Manubens, \email{nicolau.manubens@ic3.cat})  -  Formatting to CRAN
}
\keyword{datagen}
